@@ -13,6 +13,7 @@
 
 
 #include "fieldmeter.h"
+#include "xosview.h"
 
 
 class CoreTemp : public FieldMeter {
@@ -24,12 +25,15 @@ public:
 	void checkevent( void );
 	void checkResources( void );
 
+	static unsigned int countCpus( void );
+
 protected:
 	void getcoretemp( void );
 
 private:
-	int   cpu_;
-	float oldtotal_;
+	int   cpu_, cpucount_;
+	float high_, *temps_;
+	unsigned long actcolor_, highcolor_;
 };
 
 
