@@ -10,11 +10,10 @@
 //    authors for a copy.
 //
 
+#include "diskmeter.h"
+#include "kernel.h"
 #include <stdlib.h>
 #include <err.h>
-#include <sys/types.h>
-#include "kernel.h"
-#include "diskmeter.h"
 
 
 DiskMeter::DiskMeter( XOSView *parent, double max )
@@ -62,7 +61,7 @@ void DiskMeter::checkevent( void ) {
 }
 
 void DiskMeter::getstats( void ) {
-	u_int64_t reads = 0, writes = 0;
+	uint64_t reads = 0, writes = 0;
 	//  Reset to desired full-scale settings.
 	total_ = maxBandwidth_;
 
