@@ -8,8 +8,10 @@
 #define _FIELDMETER_H_
 
 #include "meter.h"
+#include "xosview.h"
 #include "timer.h"
 
+
 class FieldMeter : public Meter {
 public:
   FieldMeter( XOSView *parent, int numfields,
@@ -17,17 +19,13 @@ public:
 	      int docaptions = 0, int dolegends = 0, int dousedlegends = 0 );
   virtual ~FieldMeter( void );
 
-  virtual void drawfields( int manditory = 0 );
+  virtual void drawfields( int mandatory = 0 );
   void setfieldcolor( int field, const char *color );
   void setfieldcolor( int field, unsigned long color);
   void docaptions( int val ) { docaptions_ = val; }
   void dolegends( int val ) { dolegends_ = val; }
   void dousedlegends( int val ) { dousedlegends_ = val; }
   void reset( void );
-    /*  These next two are deprecated -- use setUsed instead.  bgrayson  */
-  void used_obsolete( int val ) { print_ = PERCENT; used_ = val; }
-  void absolute_obsolete( float val ) { print_ = FLOAT; used_ = val; }
-
   void setUsed (double val, double total);
   void draw( void );
   void checkevent( void );
@@ -47,10 +45,12 @@ protected:
   UsedType print_;
   int printedZeroTotalMesg_;
   int numWarnings_;
+  bool metric_;
+  int usedoffset_;
 
   void SetUsedFormat ( const char * const str );
   void drawlegend( void );
-  void drawused( int manditory );
+  void drawused( int mandatory );
   bool checkX(int x, int width) const;
 
   void setNumFields(int n);
