@@ -16,8 +16,9 @@
 #ifndef _FIELDMETERDECAY_H_
 #define _FIELDMETERDECAY_H_
 
-#include "meter.h"
 #include "fieldmeter.h"
+#include "xosview.h"
+
 
 class FieldMeterDecay : public FieldMeter {
 public:
@@ -26,7 +27,7 @@ public:
               int docaptions = 0, int dolegends = 0, int dousedlegends = 0 );
   virtual ~FieldMeterDecay( void );
 
-  virtual void drawfields( int manditory = 0 );
+  virtual void drawfields( int mandatory = 0 );
 
 protected:
   int dodecay_;
