@@ -22,11 +22,9 @@
 //   5.  Make the checkResources () function in the meter set the
 //       useGraph_ variable according to the, e.g., xosview*cpuGraph resource.
 
-#include <fstream>
-#include <math.h>		//  For fabs()
-#include "fieldmeter.h"
 #include "fieldmetergraph.h"
-#include "xosview.h"
+#include <stdio.h>
+
 
 FieldMeterGraph::FieldMeterGraph( XOSView *parent,
 				int numfields, const char *title,
@@ -51,7 +49,7 @@ FieldMeterGraph::~FieldMeterGraph( void )
 	delete [] heightfield_;
 }
 
-void FieldMeterGraph::drawfields( int manditory )
+void FieldMeterGraph::drawfields( int mandatory )
 {
 	int i,j;
 	enum XOSView::windowVisibilityState currWinState;
@@ -60,7 +58,7 @@ void FieldMeterGraph::drawfields( int manditory )
 	{
 		// Call FieldMeterDecay code if this meter should not be
 		// drawn as a graph
-		FieldMeterDecay::drawfields( manditory );
+		FieldMeterDecay::drawfields( mandatory );
 		return;
 	}
 
@@ -116,7 +114,7 @@ void FieldMeterGraph::drawfields( int manditory )
 	currWinState = parent_->getWindowVisibilityState();
 
 	// Try to avoid having to redraw everything.
-	if (!manditory && currWinState == XOSView::FULLY_VISIBLE && currWinState == lastWinState)
+	if (!mandatory && currWinState == XOSView::FULLY_VISIBLE && currWinState == lastWinState)
 	{
 		// scroll area
 		int col_width = width_/graphNumCols_;
@@ -143,7 +141,7 @@ void FieldMeterGraph::drawfields( int manditory )
 	parent_->setStippleN(0);	//  Restore all-bits stipple.
 	if ( dousedlegends_ )
 	{
-		drawused( manditory );
+		drawused( mandatory );
 	}
 }
 
