@@ -1,6 +1,5 @@
 //
-// $Id$
-//  Initial port performed by Stefan Eilemann (eile@sgi.com)
+//  Initial port performed by Stefan Eilemann (eilemann@gmail.com)
 //
 #include "cpumeter.h"
 #include "xosview.h"
@@ -8,7 +7,7 @@
 #include <unistd.h>
 #include <ctype.h>
 #include <string.h>
-#include <strstream.h>
+#include <sstream>
 
 CPUMeter::CPUMeter(XOSView *parent, int cpuid)
     : FieldMeterGraph(parent, USED_CPU_STATES, toUpper(cpuStr(cpuid)),
@@ -19,7 +18,7 @@ CPUMeter::CPUMeter(XOSView *parent, int cpuid)
             cputime_[i][j] = 0;
 
     if ((sinfosz = sysmp(MP_SASZ, MPSA_SINFO)) < 0) {
-        cerr << "sysinfo scall interface not supported" << endl;
+           std::cerr << "sysinfo scall interface not supported" << endl;
         parent_->done(1);
         return;
     }
