@@ -5,18 +5,16 @@
 //
 
 #include "cpumeter.h"
-#include "xosview.h"
-#include <fstream>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <string>
-#include <sstream>
 #include <ctype.h>
 #include <sys/utsname.h>
+#include <string>
+#include <iostream>
+#include <fstream>
 
 static const char STATFILENAME[] = "/proc/stat";
-static const char VERSIONFILENAME[] = "/proc/sys/kernel/osrelease";
 static int cputime_to_field[10] = { 0, 1, 2, 9, 5, 4, 3, 8, 6, 7 };
 
 #define MAX_PROCSTAT_LENGTH 4096
@@ -318,7 +316,6 @@ int CPUMeter::countCPUs(void){
 
 const char *CPUMeter::cpuStr(int num){
   static char buffer[32];
-  std::ostringstream str;
 
   if (num != 0)
     snprintf(buffer, sizeof(buffer), "cpu%d", num - 1);
