@@ -5,10 +5,12 @@
 #define _CPUMETER_H_
 
 #include "fieldmetergraph.h"
-
+#include "xosview.h"
+#include "kstats.h"
 #include <kstat.h>
 #include <sys/sysinfo.h>
 
+
 class CPUMeter : public FieldMeterGraph {
  public:
 	CPUMeter(XOSView *parent, kstat_ctl_t *kcp, int cpuid = 0);
@@ -16,10 +18,7 @@ class CPUMeter : public FieldMeterGraph {
 
 	const char *name(void) const { return "CPUMeter"; }
 	void checkevent(void);
-
 	void checkResources(void);
-
-	static int countCPUs(kstat_ctl_t *kc);
 	static const char *cpuStr(int num);
 
  protected:
@@ -27,9 +26,10 @@ class CPUMeter : public FieldMeterGraph {
 	int cpuindex_;
 
 	void getcputime(void);
-	const char *toUpper(const char *str);
 
  private:
+	KStatList *cpustats;
+	bool aggregate;
 	kstat_ctl_t *kc;
 	kstat_t *ksp;
 };
