@@ -4,9 +4,6 @@
 //  This file may be distributed under terms of the GPL
 //
 
-#include <unistd.h>
-#include <stdlib.h>
-#include <sys/time.h>
 #include "xosview.h"
 #include "meter.h"
 #include "MeterMaker.h"
@@ -14,6 +11,11 @@
       defined(XOSVIEW_OPENBSD) || defined(XOSVIEW_DFBSD) )
 # include "kernel.h"
 #endif
+#include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <iostream>
 
 static const char * const versionString = "xosview version: Git";
 
@@ -128,9 +130,8 @@ XOSView::XOSView( const char * instName, int argc, char *argv[] ) : XWin(),
   for (int i = 1 ; i <= mm.n() ; i++)
     addmeter(mm[i]);
 
-  if (nummeters_ == 0)
-  {
-    fprintf (stderr, "No meters were enabled!  Exiting...\n");
+  if (nummeters_ == 0) {
+    std::cerr << "No meters were enabled!  Exiting..." << std::endl;
     exit (0);
   }
 
@@ -159,9 +160,9 @@ void XOSView::checkVersion(int argc, char *argv[]) const
 void XOSView::figureSize ( void ) {
   if ( legend_ ){
     if ( !usedlabels_ )
-      xoff_ = textWidth( "XXXXX" );
+      xoff_ = textWidth( "XXXXXX" );
     else
-      xoff_ = textWidth( "XXXXXXXXX" );
+      xoff_ = textWidth( "XXXXXXXXXX" );
 
     yoff_ = caption_ ? textHeight() + textHeight() / 4 : 0;
   }
